searchNodes=[{"ref":"KeywordValidator.html","title":"KeywordValidator","type":"module","doc":"Functions for validating keyword lists. The main function in this module is validate/2, which allows developers to validate a keyword list against a given schema. A schema is simply a map that matches the keys for the keyword list. The values in the schema represent the options available during validation. iex&gt; KeywordValidator.validate([foo: :foo], %{foo: [type: :atom, required: true]}) {:ok, [foo: :foo]} iex&gt; KeywordValidator.validate([foo: :foo], %{foo: [inclusion: [:one, :two]]}) {:error, [foo: [&quot;must be one of: [:one, :two]&quot;]]}"},{"ref":"KeywordValidator.html#validate/3","title":"KeywordValidator.validate/3","type":"function","doc":"Validates a keyword list using the provided schema. A schema is a simple map, with each key representing a key in your keyword list. The values in the map represent the options available for validation. If the validation passes, we are returned a two-item tuple of {:ok, keyword}. Otherwise, returns {:error, invalid} - where invalid is a keyword list of errors. Schema Options :required - boolean representing whether the key is required or not, defaults to false :default - the default value for the key if not provided one, defaults to nil :type - the type associated with the key value. must be one of val_type/0 :format - a regex used to validate string format :inclusion - a list of items that the value must be a included in :exclusion - a list of items that the value must not be included in :custom - a list of two-arity functions or tuples in the format {module, function} that serve as custom validators. the function will be given the key and value as arguments, and must return a list of string errors (or an empty list if no errors are present) Options :strict - boolean representing whether extra keys will become errors, defaults to true Examples iex&gt; KeywordValidator.validate([foo: :foo], %{foo: [type: :atom, required: true]}) {:ok, [foo: :foo]} iex&gt; KeywordValidator.validate([foo: :foo], %{bar: [type: :any]}) {:error, [foo: [&quot;is not a valid key&quot;]]} iex&gt; KeywordValidator.validate([foo: :foo], %{bar: [type: :any]}, strict: false) {:ok, []} iex&gt; KeywordValidator.validate([foo: :foo], %{foo: [inclusion: [:one, :two]]}) {:error, [foo: [&quot;must be one of: [:one, :two]&quot;]]} iex&gt; KeywordValidator.validate([foo: {:foo, 1}], %{foo: [type: {:tuple, {:atom, :integer}}]}) {:ok, [foo: {:foo, 1}]} iex&gt; KeywordValidator.validate([foo: [&quot;one&quot;, 2]], %{foo: [type: {:list, :binary}]}) {:error, [foo: [&quot;must be a list of type :binary&quot;]]} iex&gt; KeywordValidator.validate([foo: &quot;foo&quot;], %{foo: [format: ~r/foo/]}) {:ok, [foo: &quot;foo&quot;]} iex&gt; KeywordValidator.validate([foo: %Foo{}], %{foo: [type: {:struct, Bar}]}) {:error, [foo: [&quot;must be a struct of type Bar&quot;]]} iex&gt; KeywordValidator.validate([foo: &quot;foo&quot;], %{foo: [custom: [fn key, val -&gt; [&quot;some error&quot;] end]]}) {:error, [foo: [&quot;some error&quot;]]}"},{"ref":"KeywordValidator.html#validate!/3","title":"KeywordValidator.validate!/3","type":"function","doc":"The same as validate/2 but raises an ArgumentError exception if invalid. Example iex&gt; KeywordValidator.validate!([foo: :foo], %{foo: [type: :atom, required: true]}) [foo: :foo] iex&gt; KeywordValidator.validate!([foo: :foo], %{foo: [inclusion: [:one, :two]]}) ** (ArgumentError) Invalid keyword given. Keyword: [foo: :foo] Invalid: foo: [&quot;must be one of: [:one, :two]&quot;]"},{"ref":"KeywordValidator.html#t:invalid/0","title":"KeywordValidator.invalid/0","type":"type","doc":""},{"ref":"KeywordValidator.html#t:key_opt/0","title":"KeywordValidator.key_opt/0","type":"type","doc":""},{"ref":"KeywordValidator.html#t:key_opts/0","title":"KeywordValidator.key_opts/0","type":"type","doc":""},{"ref":"KeywordValidator.html#t:option/0","title":"KeywordValidator.option/0","type":"type","doc":""},{"ref":"KeywordValidator.html#t:options/0","title":"KeywordValidator.options/0","type":"type","doc":""},{"ref":"KeywordValidator.html#t:schema/0","title":"KeywordValidator.schema/0","type":"type","doc":""},{"ref":"KeywordValidator.html#t:val_type/0","title":"KeywordValidator.val_type/0","type":"type","doc":""},{"ref":"readme.html","title":"KeywordValidator","type":"extras","doc":"KeywordValidator KeywordValidator provides a simple interface to validate keyword lists in Elixir."},{"ref":"readme.html#installation","title":"KeywordValidator - Installation","type":"extras","doc":"The package can be installed by adding keyword_validator to your list of dependencies in mix.exs: def deps do [ {:keyword_validator, &quot;~&gt; 0.4&quot;} ] end"},{"ref":"readme.html#documentation","title":"KeywordValidator - Documentation","type":"extras","doc":"Please see HexDocs for additional documentation."},{"ref":"readme.html#getting-started","title":"KeywordValidator - Getting Started","type":"extras","doc":"To begin validating, we must first create a schema that defines the rules for our keyword list. A schema is a simple map, with each key representing a key in your keyword list. The values in the map represent the options available for validation. If the validation passes, we are returned a valid keyword list. iex&gt; keyword = [foo: :foo, bar: &quot;one&quot;] iex&gt; schema = %{foo: [type: :atom, required: true], bar: [inclusion: [&quot;one&quot;, &quot;two&quot;, &quot;three&quot;]]} iex&gt; KeywordValidator.validate(keyword, schema) {:ok, [foo: :foo, bar: &quot;one&quot;]} If validation fails on any of the keys, a keyword list of the invalid entries and the associated errors is returned. iex&gt; keyword = [foo: :foo, bar: :bar] iex&gt; schema = %{foo: [type: :binary], bar: [inclusion: [:one, :two, :three]]} iex&gt; KeywordValidator.validate(keyword, schema) {:error, [bar: [&quot;must be one of: [:one, :two, :three]&quot;], foo: [&quot;must be a binary&quot;]]} We can optionally use the KeywordValidator.validate!/2 function as well - which will raise an error that describes the invalid key entries. ** (ArgumentError) Invalid keyword given. Keyword: [foo: :foo, bar: :bar] Invalid: bar: [&quot;must be one of: [:one, :two, :three]&quot;] foo: [&quot;must be a binary&quot;] To view all the available validation options, please check out the relevant documentation."}]